==> nextcloud-30.0.14.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ca.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Heu creat els codis de reserva de dos factors per al vostre compte",
    "Second-factor backup codes" : "Codis de reserva de dos factors",
    "Generate backup codes" : "Genera els codis de reserva",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Heu habilitat l'autenticació de dos factors, però encara no heu generat codis de reserva. Els necessitareu per a restablir l'accés al compte si perdeu el segon factor.",
    "Backup code" : "Codi de reserva",
    "Use backup code" : "Utilitza un codi de reserva",
    "Two factor backup codes" : "Codis de reserva de l'autenticació de dos factors",
    "A two-factor auth backup codes provider" : "Proveïdor de codis de reserva de l'autenticació de dos factors",
    "An error occurred while generating your backup codes" : "S'ha produït un error en generar els codis de reserva",
    "Backup codes have been generated. {used} of {total} codes have been used." : "S'han generat els codis de reserva. Heu utilitzat {used} de {total} codis.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Aquests són els vostres codis de reserva. Deseu-los o imprimiu-los, ja que no podreu tornar-los a consultar més tard.",
    "Save backup codes" : "Desa els codis de reserva",
    "Print backup codes" : "Imprimeix els codis de reserva",
    "Regenerate backup codes" : "Torna a generar els codis de reserva",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si torneu a generar els codis de reserva, anul·lareu automàticament els codis antics.",
    "{name} backup codes" : "Codis de seguretat per a {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilitzeu un dels codis de reserva que vau desar en configurar l'autenticació de dos factors.",
    "Submit" : "Envia"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/ca.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Heu creat els codis de reserva de dos factors per al vostre compte",
    "Second-factor backup codes" : "Codis de reserva de dos factors",
    "Generate backup codes" : "Genera els codis de reserva",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Heu habilitat l'autenticació de dos factors, però encara no heu generat codis de reserva. Els necessitareu per a restablir l'accés al compte si perdeu el segon factor.",
    "Backup code" : "Codi de reserva",
    "Use backup code" : "Utilitza un codi de reserva",
    "Two factor backup codes" : "Codis de reserva de l'autenticació de dos factors",
    "A two-factor auth backup codes provider" : "Proveïdor de codis de reserva de l'autenticació de dos factors",
    "An error occurred while generating your backup codes" : "S'ha produït un error en generar els codis de reserva",
    "Backup codes have been generated. {used} of {total} codes have been used." : "S'han generat els codis de reserva. Heu utilitzat {used} de {total} codis.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Aquests són els vostres codis de reserva. Deseu-los o imprimiu-los, ja que no podreu tornar-los a consultar més tard.",
    "Save backup codes" : "Desa els codis de reserva",
    "Print backup codes" : "Imprimeix els codis de reserva",
    "Regenerate backup codes" : "Torna a generar els codis de reserva",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si torneu a generar els codis de reserva, anul·lareu automàticament els codis antics.",
    "{name} backup codes" : "Codis de seguretat per a {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilitzeu un dels codis de reserva que vau desar en configurar l'autenticació de dos factors.",
    "Submit" : "Envia",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Aquests són els vostres codis de reserva. Deseu-los o imprimiu-los, ja que no podreu tornar-los a consultar més tard"
},
"nplurals=2; plural=(n != 1);");
